local _, ns = ...
local SyLevel = ns.SyLevel

local argcheck = SyLevel.argcheck

local GREY = {0.55,0.55,0.55}
local RED = {1,0,0}
local ORANGE = {1,0.7,0}
local YELLOW = {1,1,0}
local GREEN = {0,1,0}
local LIGHTBLUE = {0,1,1}
local BLUE = {0,0.8,1}
local DARKBLUE = {0,0.5,1}
local PURPLE = {0.7,0,1}
local PINK = {1,0,1}
local WHITE = {1,1,1}
local HEIRLOOM = {0.9, 0.8, 0.5}

--[[ Do not edit beyond this point ]]-- 

local colors = {
	WHITE, 				-- 1 
	PINK, 				-- 2
	PURPLE, 			-- 3
	DARKBLUE, 			-- 4
	BLUE, 				-- 5
	LIGHTBLUE, 			-- 6
	GREEN, 				-- 7
	YELLOW, 			-- 8
	ORANGE, 			-- 9
	RED, 				-- 10
	{0.8, 0.8, 0.8}, 	-- 11
	{0.66, 0.66, 0.66}, -- 12
	{0.55, 0.55, 0.55}, -- 13
}

local ilvls = {
	509, -- 1
	502, -- 2
	496, -- 3
	489, -- 4
	483, -- 5
	476, -- 6
	463, -- 7
	450, -- 8
	400, -- 9
	350, -- 10
	300, -- 11
	250, -- 12
	1 -- 13	
}

local function BuildRelative(e)
	local t = {}
	local start = (e / 12)
	local increment = (start / 6)
	for i=1,12 do
		start = start - increment
		if (start + e) > 1 then
			t[i] = start + e			
		else
			t[i] = 1
		end	
	end
	t[13] = 1 -- Always make level 1 items grey.
	
	return t
end

local colorFunctions = {
	[1] = function(ilvl)
		argcheck(ilvl,2,'number')
		ilvl = (ilvl / 608)
		local r,g,b
		if ilvl < .5 then
			r = ilvl*2
			g = 1
			b = 0
		else
			r = 1
			g = 1-(ilvl-0.5)*2
			b = 0
		end
		return r, g, b
	end,
	[2] = function(ilvl)
		argcheck(ilvl,2,'number')
		ilvl = (ilvl / 608)
		local r,g,b
		if ilvl < .5 then
			r = 1
			g = ilvl*2
			b = 0
		else
			r = 1-(ilvl-0.5)*2
			g = 1
			b = 0
		end
		return r, g, b
	end,
	[3] = function(ilvl)
		argcheck(ilvl,2,'number')
		for i=1,#ilvls do
			if ilvl >= ilvls[i] then
				return unpack(colors[i] or {0.3,0.3,0.3})
			end
		end		
	end,
	[4] = function(ilvl)
		argcheck(ilvl,2,'number')
		local o, e = GetAverageItemLevel()
		local relative = BuildRelative(e)
		for i=1,#relative do
			if ilvl >= relative[i] then
				return unpack(colors[i] or {0.55,0.55,0.55})
			end
		end	
	end
}

function SyLevel:SetColorFunc(index)
	SyLevelDB.ColorFunc = index
	for pipe, active, name, desc in SyLevel.IteratePipes() do
		if(active) then
			SyLevel:UpdatePipe(pipe)
		end
	end
end

function SyLevel:GetColorFunc()
	return colorFunctions[SyLevelDB.ColorFunc]
end

--[[

local colorTable = setmetatable(
	{},

	-- We mainly want to handle item quality coloring, so this acts as a fallback.
	-- The bonus of doing this is that we don't really have to make any updates to
	-- the add-on if any new item colors are added. It also caches unlike the old
	-- version.
	{__index = function(self, val)
		argcheck(val, 2, 'number')
		local r, g, b = GetItemQualityColor(val)
		rawset(self, val, {r, g, b})

		return self[val]
	end}
)

function SyLevel:RegisterColor(name, r, g, b)
	argcheck(name, 2, 'string', 'number')
	argcheck(r, 3, 'number')
	argcheck(g, 4, 'number')
	argcheck(b, 5, 'number')

	local color = rawget(colorTable, name)
	if(color) then
		color[1], color[2], color[3] = r, g, b
	else
		color = {r, g, b}
		rawset(colorTable, name, color)
	end

	SyLevelDB.Colors[name] = color

	return true
end

function SyLevel:ResetColor(name)
	argcheck(name, 2, 'string', 'number')

	SyLevelDB.Colors[name] = nil
	colorTable[name] = nil

	return unpack(colorTable[name])
end

ns.colorTable = colorTable]]